@@ -1,6 +1,6 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '2.2.1';
+$Git::Hooks::VERSION = '2.3.0';
 use 5.010;
 use strict;
 use warnings;
@@ -83,7 +83,7 @@ sub run_hook {
     if (my $errors = $git->get_errors()) {
         $errors .= "\n" unless $errors =~ /\n$/;
         if (($hook_basename eq 'commit-msg' or $hook_basename eq 'pre-commit')
-                and not $git->get_config(githooks => 'abort-commit')) {
+                and not $git->get_config_boolean(githooks => 'abort-commit')) {
             warn $errors;
         } else {
             die $errors;
@@ -108,7 +108,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 2.2.1
+version 2.3.0
 
 =head1 SYNOPSIS
 
@@ -543,7 +543,7 @@ We just have to change the check_new_files function:
     sub check_new_files {
         my ($git, $commit, @files) = @_;
 
-        my $limit = $git->get_config('githooks.checkfilesize', 'limit');
+        my $limit = $git->get_config_integer('githooks.checkfilesize', 'limit');
 
         return 1 unless defined $limit;   # By default there is no limit
 
@@ -905,7 +905,7 @@ This option specify a list of directories where plugins are looked for
 besides the default locations, as explained in the C<githooks.plugin>
 option above.
 
-=head2 githooks.externals [01]
+=head2 githooks.externals BOOL
 
 By default the driver script will look for external hooks after
 executing every enabled plugins. You may disable external hooks
@@ -1025,16 +1025,16 @@ anchored at the start of the username.
 
 =back
 
-=head2 githooks.abort-commit [01]
+=head2 githooks.abort-commit BOOL
 
-This option is true (1) by default, meaning that the C<pre-commit> and
+This option is true by default, meaning that the C<pre-commit> and
 the C<commit-msg> hooks will abort the commit if they detect anything
 wrong in it. This may not be the best way to handle errors, because
 you must remember to retrieve your carefully worded commit message
 from the C<.git/COMMIT_EDITMSG> to try it again, and it is easy to
 forget about it and lose it.
 
-Setting this to false (0) makes these hooks simply warn the user via
+Setting this to false makes these hooks simply warn the user via
 STDERR but let the commit succeed. This way, the user can correct any
 mistake with a simple C<git commit --amend> and doesn't run the risk
 of losing the commit message.
@@ -1091,7 +1091,7 @@ a comment like this in addition to casting the vote:
 
 You may want to use a simple comment like 'OK'.
 
-=head2 githooks.gerrit.auto-submit [01]
+=head2 githooks.gerrit.auto-submit BOOL
 
 If this option is enabled, Git::Hooks will try to automatically submit a
 change if all verification hooks pass.
