@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckCommit;
 # ABSTRACT: Git::Hooks plugin to enforce commit policies
-$Git::Hooks::CheckCommit::VERSION = '2.2.1';
+$Git::Hooks::CheckCommit::VERSION = '2.3.0';
 use 5.010;
 use utf8;
 use strict;
@@ -25,6 +25,10 @@ sub _setup_config {
 
     $config->{lc $CFG} //= {};
 
+    my $default = $config->{lc $CFG};
+
+    $default->{'push-limit'} //= [0];
+
     return;
 }
 
@@ -93,14 +97,14 @@ sub email_valid_errors {
 
     my $cache = $git->cache($PKG);
 
-    if ($git->get_config($CFG => 'email-valid')) {
+    if ($git->get_config_boolean($CFG => 'email-valid')) {
         # Let's also cache the Email::Valid object
         unless (exists $cache->{email_valid}) {
             $cache->{email_valid} = undef;
             if (eval { require Email::Valid; }) {
                 my @checks;
                 foreach my $check (qw/mxcheck tldcheck fqdn allow_ip/) {
-                    if (my $value = $git->get_config($CFG => "email-valid.$check")) {
+                    if (my $value = $git->get_config_boolean($CFG => "email-valid.$check")) {
                         push @checks, "-$check" => $value;
                     }
                 }
@@ -281,7 +285,7 @@ sub check_ref {
 
     my @commits = $git->get_affected_ref_commits($ref);
 
-    if (my $limit = $git->get_config($CFG => 'push-limit')) {
+    if (my $limit = $git->get_config_integer($CFG => 'push-limit')) {
         if (@commits > $limit) {
             $git->error($PKG, "you're pushing @{[scalar @commits]} commits to $ref, more than our current limit of $limit");
             ++$errors;
@@ -389,7 +393,7 @@ Git::Hooks::CheckCommit - Git::Hooks plugin to enforce commit policies
 
 =head1 VERSION
 
-version 2.2.1
+version 2.3.0
 
 =head1 DESCRIPTION
 
@@ -475,7 +479,7 @@ negative regular expressions (the ones prefixed by "!").
 
 This check is performed by the C<pre-commit> local hook.
 
-=head2 githooks.checkcommit.email-valid [01]
+=head2 githooks.checkcommit.email-valid BOOL
 
 This option uses the L<Email::Valid> module' C<address> method to validate
 author and committer email addresses.
@@ -491,22 +495,22 @@ the boolean parameters to change their default values by means of the
 following sub-options. For more information, please consult the
 L<Email::Valid> documentation.
 
-=head3 githooks.checkcommit.email-valid.mxcheck [01]
+=head3 githooks.checkcommit.email-valid.mxcheck BOOL
 
 Specifies whether addresses should be checked for a valid DNS entry. The
 default is false.
 
-=head3 githooks.checkcommit.email-valid.tldcheck [01]
+=head3 githooks.checkcommit.email-valid.tldcheck BOOL
 
 Specifies whether addresses should be checked for valid top level
 domains. The default is false.
 
-=head3 githooks.checkcommit.email-valid.fqdn [01]
+=head3 githooks.checkcommit.email-valid.fqdn BOOL
 
 Species whether addresses must contain a fully qualified domain name
 (FQDN). The default is true.
 
-=head3 githooks.checkcommit.email-valid.allow_ip [01]
+=head3 githooks.checkcommit.email-valid.allow_ip BOOL
 
 Specifies whether a "domain literal" is acceptable as the domain part.  That
 means addresses like: C<rjbs@[1.2.3.4]>. The default is true.
@@ -573,7 +577,7 @@ repository. WHO may be specified as a username, a groupname, or a regex,
 like the C<githooks.admin> option (see L<Git::Hooks/CONFIGURATION>) so that
 only users matching WHO may push merge commits.
 
-=head2 githooks.checkcommit.push-limit N
+=head2 githooks.checkcommit.push-limit INT
 
 This limits the number of commits that may be pushed at once on top of any
 reference. Set it to 1 to force developers to squash their commits before
