@@ -1,6 +1,6 @@
 package Git::Repository::Plugin::GitHooks;
 # ABSTRACT: A Git::Repository plugin with some goodies for hook developers
-$Git::Repository::Plugin::GitHooks::VERSION = '2.2.1';
+$Git::Repository::Plugin::GitHooks::VERSION = '2.3.0';
 use parent qw/Git::Repository::Plugin/;
 
 use 5.010;
@@ -19,7 +19,7 @@ sub _keywords {                 ## no critic (ProhibitUnusedPrivateSubroutines)
 
           cache
 
-          get_config
+          get_config get_config_boolean get_config_integer
 
           error get_errors
 
@@ -217,8 +217,12 @@ sub _gerrit_patchset_post_hook {
     my $patchset = $args->{'--patchset'};
 
     # Grok all configuration options at once to make it easier to deal with them below.
-    my %cfg = map {$_ => $git->get_config('githooks.gerrit' => $_) || undef}
-        qw/votes-to-approve votes-to-reject comment-ok auto-submit/;
+    my %cfg = (
+        'votes-to-approve' => $git->get_config('githooks.gerrit' => 'votes-to-approve'),
+        'votes-to-reject'  => $git->get_config('githooks.gerrit' => 'votes-to-reject'),
+        'comment-ok'       => $git->get_config('githooks.gerrit' => 'comment-ok'),
+        'auto-submit'      => $git->get_config_boolean('githooks.gerrit' => 'auto-submit'),
+    );
 
     # https://gerrit-documentation.storage.googleapis.com/Documentation/2.13.1/rest-api-changes.html#set-review
     my %review_input;
@@ -484,7 +488,7 @@ sub _invoke_external_hook {     ## no critic (ProhibitExcessComplexity)
 sub invoke_external_hooks {
     my ($git, @args) = @_;
 
-    return if $^O eq 'MSWin32' || ! $git->get_config(githooks => 'externals');
+    return if $^O eq 'MSWin32' || ! $git->get_config_boolean(githooks => 'externals');
 
     my $hookname = $git->{_plugin_githooks}{hookname};
 
@@ -540,26 +544,6 @@ sub get_config {
     unless (exists $git->{_plugin_githooks}{config}) {
         my %config;
 
-        exists $ENV{HOME}
-            or croak __PACKAGE__, <<'EOT';
-The HOME environment variable is undefined.
-
-We need it to read Git's global configuration from $HOME/.gitconfig.
-
-If you really don't want to read the global configuration, define HOME as an
-empty string in your hook script like this before invoking run_hook():
-
-  $ENV{HOME} = '';
-
-Note that if you're using Gerrit as a Git server it runs with HOME undefined
-by default when started by a boot script. In this case you should define
-HOME in your hook script to point to the directory holding your .gitconfig
-file. For example:
-
-  $ENV{HOME} = '/home/gerrit';
-
-EOT
-
         my $config = do {
            local $/ = "\c@";
            $git->run(qw/config --null --list/);
@@ -571,10 +555,22 @@ EOT
         }
 
         if (defined $config) {
-            while ($config =~ /([^\cJ]+)\cJ([^\c@]*)\c@/sg) {
+            # The --null option to git-log makes it output a null character
+            # after each option/value. The option and value are separated by a
+            # newline, unless there is no value, in which case, there is no
+            # newline.
+            while ($config =~ /([^\cJ]+)(\cJ[^\c@]*|)\c@/sg) {
                 my ($option, $value) = ($1, $2);
                 if ($option =~ /(.+)\.(.+)/) {
-                    push @{$config{lc $1}{lc $2}}, $value;
+                    my ($section, $key) = (lc $1, lc $2);
+                    if ($value =~ s/^\cJ//) {
+                        push @{$config{$section}{$key}}, $value;
+                    } else {
+                        # An option without a value is considered a boolean
+                        # true. We mark it explicitly so instead of leaving it
+                        # undefined because Perl would consider it false.
+                        push @{$config{$section}{$key}}, 'true';
+                    }
                 } else {
                     croak __PACKAGE__, ": Cannot grok config variable name '$option'.\n";
                 }
@@ -592,6 +588,7 @@ EOT
     my $config = $git->{_plugin_githooks}{config};
 
     $section = lc $section if defined $section;
+    $var     = lc $var     if defined $var;
 
     if (! defined $section) {
         return $config;
@@ -605,6 +602,53 @@ EOT
     }
 }
 
+sub get_config_boolean {
+    my ($git, $section, $var) = @_;
+
+    my $bool = $git->get_config($section, $var);
+
+    if (! defined $bool) {
+        return;
+    } elsif (ref $bool) {
+        croak __PACKAGE__, ": get_bool_config method requires two arguments\n";
+    } elsif ($bool =~ /^(?:yes|on|true|1)$/i) {
+        return 1;
+    } elsif ($bool =~ /^(?:no|off|false|0|)$/i) {
+        return 0;
+    } else {
+        croak __PACKAGE__, ": get_config_boolean($section, $var) not a valid boolean: '$bool'\n";
+    }
+}
+
+sub get_config_integer {
+    my ($git, $section, $var) = @_;
+
+    my $int = $git->get_config($section, $var);
+
+    if (! defined $int) {
+        return;
+    } elsif (ref $int) {
+        croak __PACKAGE__, ": get_config_integer() requires two arguments\n";
+    } elsif ($int =~ /^([+-]?)([0-9]+)([kmg]?)$/i) {
+        my ($signal, $num, $unit) = ($1, $2, lc $3);
+        if ($unit) {
+            if ($unit eq 'k') {
+                $num *= 1024;
+            } elsif ($unit eq 'm') {
+                $num *= 1024*1024;
+            } elsif ($unit eq 'g') {
+                $num *= 1024*1024*1024;
+            }
+        }
+        if ($signal eq '-') {
+            $num *= -1;
+        }
+        return $num;
+    } else {
+        croak __PACKAGE__, ": get_config_integer($section, $var) not a valid integer: '$int'\n";
+    }
+}
+
 sub error {
     my ($git, $prefix, $message, $details) = @_;
     $message =~ s/\n*$//s;    # strip trailing newlines
@@ -635,7 +679,7 @@ sub get_errors {
     $errors .= join("\n\n", @{$git->{_plugin_githooks}{errors}});
 
     if ($git->{_plugin_githooks}{hookname} =~ /^commit-msg|pre-commit$/
-            && ! $git->get_config(githooks => 'abort-commit')) {
+            && ! $git->get_config_boolean(githooks => 'abort-commit')) {
         $errors .= <<"EOF";
 
 ATTENTION: To fix the problems in this commit, please consider amending it:
@@ -773,7 +817,7 @@ sub get_commits {
 sub read_commit_msg_file {
     my ($git, $msgfile) = @_;
 
-    my $encoding = $git->get_config(i18n => 'commitencoding') || 'utf-8';
+    my $encoding = $git->get_config(i18n => 'commitEncoding') || 'utf-8';
 
     my $msg = path($msgfile)->slurp({binmode => ":encoding($encoding)"});
 
@@ -814,7 +858,7 @@ sub read_commit_msg_file {
 sub write_commit_msg_file {
     my ($git, $msgfile, @msg) = @_;
 
-    my $encoding = $git->get_config(i18n => 'commitencoding') || 'utf-8';
+    my $encoding = $git->get_config(i18n => 'commitEncoding') || 'utf-8';
 
     path($msgfile)->spew({binmode => ":encoding($encoding)"}, @msg);
 
@@ -1179,7 +1223,7 @@ Git::Repository::Plugin::GitHooks - A Git::Repository plugin with some goodies f
 
 =head1 VERSION
 
-version 2.2.1
+version 2.3.0
 
 =head1 SYNOPSIS
 
@@ -1301,7 +1345,7 @@ This groks the configuration options for the repository by invoking C<git
 config --list>. The configuration is cached during the first invocation in
 the object C<Git::Repository> object. So, if the configuration is changed
 afterwards, the method won't notice it. This is usually ok for hooks,
-though.
+though, which are short-lived.
 
 With no arguments, the options are returned as a hash-ref pointing to a
 two-level hash. For example, if the config options are these:
@@ -1367,6 +1411,39 @@ returns the list of all values or the empty list, if the variable isn't
 defined. In scalar context, the method returns the variable's last value or
 C<undef>, if it's not defined.
 
+As a special case, options without values (i.e., with no equals sign after its
+name in the configuration file) are set to the string 'true' to force Perl
+recognize them as true booleans.
+
+=head2 get_config_boolean SECTION VARIABLE
+
+Git configuration variables may be grokked as booleans. (See C<git help
+config>.)  There are specific values meaning B<true> (viz. C<yes>, C<on>,
+C<true>, C<1>, and the absense of a value) and specific values meaning B<false>
+(viz. C<no>, C<off>, C<false>, C<0>, and the empty string).
+
+This method checks the variable's value and returns 1 or 0 representing boolean
+values in Perl. If the variable's value isn't recognized as a Git boolean the
+method croaks. If the variable isn't defined the method returns undef.
+
+In the L<Git::Hooks> documentation, all configuration variables mentioning a
+C<BOOL> value are grokked with this method.
+
+=head2 get_config_integer SECTION VARIABLE
+
+Git configuration variables may be grokked as integers. (See C<git help
+config>.)  They may start with an optional signal (C<+> or C<->), followed by
+one or more decimal digits, and end with an optional scaling factor letter,
+viz. C<k> (1024), C<m> (1024*1024), or C<g> (1024*1024*1024). The scaling factor
+may be in lower or upper-case.
+
+This method checks the variable's value format and returns the corresponding
+Perl integer.  If the variable's value isn't recognized as a Git integer the
+method croaks. If the variable isn't defined the method returns undef.
+
+In the L<Git::Hooks> documentation, all configuration variables mentioning an
+C<INT> value are grokked with this method.
+
 =head2 error PREFIX MESSAGE [DETAILS]
 
 This method should be used by plugins to record consistent error or warning
